@@ -129,11 +129,11 @@ function `string-to-number'."
 
 (defsubst eshell-under-xemacs-p ()
   "Return non-nil if we are running under XEmacs."
-  (boundp 'xemacs-logo))
+  (or (featurep 'xemacs) (featurep 'sxemacs)))
 
 (defsubst eshell-under-windows-p ()
   "Return non-nil if we are running under MS-DOS/Windows."
-  (memq system-type '(ms-dos windows-nt)))
+ (memq system-type '(ms-dos windows-nt cygwin32)))
 
 (defmacro eshell-condition-case (tag form &rest handlers)
   "Like `condition-case', but only if `eshell-pass-through-errors' is nil."
